@@ -19,9 +19,7 @@
 #    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ###################
 
-"""This package implements a web server to run scripts or 
-executables from the command line and display the result 
-in a web interface.
+"""This tools run scripts and display the result in a Web Interface.
 
 This file implement some functions to manage WebScript default databases."""
 
@@ -30,8 +28,8 @@ __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
 __maintainer_email__ = "mauricelambert434@gmail.com"
-__description__ = """This package implements a web server to run scripts or 
-executables from the command line and display the result in a web interface.
+__description__ = """
+This tools run scripts and display the result in a Web Interface.
 
 This file implement some functions to manage WebScript default databases"""
 __license__ = "GPL-3.0 License"
@@ -66,6 +64,7 @@ from secrets import randbelow, token_bytes
 from base64 import b64encode, b64decode
 from collections.abc import Iterator
 from collections import namedtuple
+from hmac import compare_digest
 from hashlib import pbkdf2_hmac
 from os import environ, path
 from fnmatch import fnmatch
@@ -275,15 +274,15 @@ def auth_username_password(name: str, password: str) -> User:
         if (
             user.password
             and user.name == name
-            and b64encode(
+            and compare_digest(
                 pbkdf2_hmac(
                     "sha512",
                     password.encode(),
                     b64decode(user.salt.encode()),
                     int(user.enumerations),
-                )
-            ).decode()
-            == user.password
+                ),
+                b64decode(user.password),
+            )
         ):
             for glob_ip in user.IPs.split(","):
                 if fnmatch(environ["REMOTE_ADDR"], glob_ip):
